@@ -25,9 +25,9 @@
 #include <tqstringlist.h>
 #include <tqmap.h>
 
-#include <kmainwindow.h>
+#include <tdemainwindow.h>
 #include <dcopobject.h>
-#include <kfileitem.h>
+#include <tdefileitem.h>
 #include <kurl.h>
 
 // forward declarations
@@ -40,17 +40,17 @@ class TQVBox;
 class TQTimer;
 class TQSplitter;
 
-namespace KIO { class Job; }
+namespace TDEIO { class Job; }
 
 class KMenuBar;
-class KToolBar;
+class TDEToolBar;
 class KStatusBar;
 class KSystemTray;
-class KAction;
-class KRadioAction;
-class KActionMenu;
+class TDEAction;
+class TDERadioAction;
+class TDEActionMenu;
 class KHistoryCombo;
-class KToggleAction;
+class TDEToggleAction;
 class KBookmarkMenu;
 
 class SQ_SplashScreen;
@@ -75,10 +75,10 @@ class SQ_SlideShowListing;
  *  Main widget, which can accept DCOP messages
  */
 
-class KSquirrel : public KMainWindow, public DCOPObject
+class KSquirrel : public TDEMainWindow, public DCOPObject
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 
     public:
         /*
@@ -139,13 +139,13 @@ class KSquirrel : public KMainWindow, public DCOPObject
         /*
          *  Return popup menu with filters for filemanager.
          */
-        KPopupMenu* menuFilters();
+        TDEPopupMenu* menuFilters();
 
         /*
          *  Return popup menu with view types - 
          *  Icon view, Detail view ...
          */
-        KPopupMenu* menuViews();
+        TDEPopupMenu* menuViews();
 
         /*
          *  Get pointer to a widget, located in status bar.
@@ -207,7 +207,7 @@ class KSquirrel : public KMainWindow, public DCOPObject
          *  Create location toolbar and store a pointer to
          *  it in passed argument.
          */
-        void createLocationToolbar(KToolBar *);
+        void createLocationToolbar(TDEToolBar *);
 
         /*
          *  Create statusbar.
@@ -217,7 +217,7 @@ class KSquirrel : public KMainWindow, public DCOPObject
         /*
          *  Create main toolbar.
          */
-        void createToolbar(KToolBar *);
+        void createToolbar(TDEToolBar *);
 
         /*
          *  Create main menu.
@@ -225,7 +225,7 @@ class KSquirrel : public KMainWindow, public DCOPObject
         void createMenu(KMenuBar *);
 
         /*
-         *  Create all KActions
+         *  Create all TDEActions
          */
         void createActions();
 
@@ -261,7 +261,7 @@ class KSquirrel : public KMainWindow, public DCOPObject
         void handlePositionSize();
 
         /*
-         *  If user-depended config file doesn't exist (~/.kde/share/config/ksquirrelrc),
+         *  If user-depended config file doesn't exist (~/.trinity/share/config/ksquirrelrc),
          *  create it and write default entries. Called before SQ_Config object is being
          *  created
          */
@@ -379,8 +379,8 @@ class KSquirrel : public KMainWindow, public DCOPObject
 
     private slots:
 
-        void slotStatResult(KIO::Job *job);
-        void slotDCOPStatResult(KIO::Job *job);
+        void slotStatResult(TDEIO::Job *job);
+        void slotDCOPStatResult(TDEIO::Job *job);
 
         void slotPreviewWidgetNext();
         void slotPreviewWidgetPrevious();
@@ -388,7 +388,7 @@ class KSquirrel : public KMainWindow, public DCOPObject
 
         void slotSaveYourself();
         void slotRename();
-        void slotRenameResult(KIO::Job *);
+        void slotRenameResult(TDEIO::Job *);
         void slotExtendedToggled(bool);
         void slotTrayQuit();
         void slotClose();
@@ -413,12 +413,12 @@ class KSquirrel : public KMainWindow, public DCOPObject
         /*
          *  Got new urls while listing directory for slideshow
          */
-        void slotSlideShowEntries(KIO::Job *, const KIO::UDSEntryList &);
+        void slotSlideShowEntries(TDEIO::Job *, const TDEIO::UDSEntryList &);
 
         /*
          *  Directory listed for slideshow
          */
-        void slotSlideShowJobResult(KIO::Job *);
+        void slotSlideShowJobResult(TDEIO::Job *);
 
         void slotSlideShowListingKill();
 
@@ -544,38 +544,38 @@ class KSquirrel : public KMainWindow, public DCOPObject
 
         bool m_demo;
 
-        KToggleAction *pAThumbsE;
+        TDEToggleAction *pAThumbsE;
 
         // main toolbar
-        KToolBar    *tools;
+        TDEToolBar    *tools;
 
         //main menu
         KMenuBar    *menubar;
 
         // different views (Icon view, List view ...)
-        KRadioAction    *pARaiseListView, *pARaiseIconView, *pARaiseDetailView, *pARaiseThumbView;
+        TDERadioAction    *pARaiseListView, *pARaiseIconView, *pARaiseDetailView, *pARaiseThumbView;
 
         // popup menu with thumbnail sizes
-        KActionMenu    *pAThumbs;
+        TDEActionMenu    *pAThumbs;
 
         // thumbnail sizes (small, normal, ...)
-        KRadioAction    *pAThumb0, *pAThumb1, *pAThumb2, *pAThumb3;
+        TDERadioAction    *pAThumb0, *pAThumb1, *pAThumb2, *pAThumb3;
 
         // show/hide url box
-        KToggleAction    *pAURL;
+        TDEToggleAction    *pAURL;
 
         // popup menus: "File", "View" ...
-        KPopupMenu    *pop_file, *pop_view, *pop_action, *pop_nav;
+        TDEPopupMenu    *pop_file, *pop_view, *pop_action, *pop_nav;
 
         // filters and views
-        KPopupMenu    *actionFilterMenu, *actionViews;
+        TDEPopupMenu    *actionFilterMenu, *actionViews;
 
         // menus with bookmarks
-        KActionMenu     *bookmarks;
+        TDEActionMenu     *bookmarks;
         KBookmarkMenu    *bookmarkMenu;
 
         // "Open file", "open file #2"
-        KAction    *pAOpen, *pAOpenAndSet,
+        TDEAction    *pAOpen, *pAOpenAndSet,
 
         *pARename,
 
@@ -646,14 +646,14 @@ class KSquirrel : public KMainWindow, public DCOPObject
         TQStringList    *sqFiltersName, *sqFiltersExt;
 
         // "Configure KSquirrel"
-        KAction    *pAConfigure,
+        TDEAction    *pAConfigure,
 
         // "Select group", "Deselect group", "Select all", "Deselect"
         // actions for filemanager
         *pASelectGroup, *pADeselectGroup, *pASelectAll, *pADeselectAll;
 
         // "Slideshow"
-        KAction    *pASlideShow;
+        TDEAction    *pASlideShow;
 
         /*
          * Slideshow-specififc members.
@@ -662,7 +662,7 @@ class KSquirrel : public KMainWindow, public DCOPObject
          */
         bool slideShowPaused;
 
-        KIO::Job *listing;
+        TDEIO::Job *listing;
 
         SQ_SlideShowListing *listingDialog;
 
@@ -691,10 +691,10 @@ class KSquirrel : public KMainWindow, public DCOPObject
         bool    slideShowStop;
 
         // url box
-        KToolBar    *pTLocation;
+        TDEToolBar    *pTLocation;
 
         // our config file
-        SQ_Config    *kconf;
+        SQ_Config    *tdeconf;
 
         // widget stack containing different views (Icon view, List view ...)
         SQ_WidgetStack    *pWidgetStack;
@@ -775,13 +775,13 @@ TQStringList* KSquirrel::filtersExtensions() const
 }
 
 inline
-KPopupMenu* KSquirrel::menuFilters()
+TDEPopupMenu* KSquirrel::menuFilters()
 {
     return actionFilterMenu;
 }
 
 inline
-KPopupMenu* KSquirrel::menuViews()
+TDEPopupMenu* KSquirrel::menuViews()
 {
     return actionViews;
 }
