@@ -27,16 +27,16 @@
 #include <tqpainter.h>
 #include <tqpaintdevicemetrics.h>
 
-#include <kapplication.h>
-#include <kaction.h>
+#include <tdeapplication.h>
+#include <tdeaction.h>
 #include <kstandarddirs.h>
-#include <klocale.h>
-#include <kpopupmenu.h>
+#include <tdelocale.h>
+#include <tdepopupmenu.h>
 #include <ktabbar.h>
 #include <kcursor.h>
-#include <ktempfile.h>
-#include <kmessagebox.h>
-#include <kfileitem.h>
+#include <tdetempfile.h>
+#include <tdemessagebox.h>
+#include <tdefileitem.h>
 #include <kprinter.h>
 
 #include <algorithm>
@@ -78,18 +78,18 @@
 // Create actions
 void SQ_GLWidget::createActions()
 {
-    pASelectionRect = new KToggleAction(i18n("Rectangle"), TQPixmap(locate("data", "images/actions/glselection_rect.png")), 0, TQT_TQOBJECT(this), TQT_SLOT(slotSelectionRect()), ac, "SQ Selection Rect");
-    pASelectionEllipse = new KToggleAction(i18n("Ellipse"), TQPixmap(locate("data", "images/actions/glselection_ellipse.png")), 0, TQT_TQOBJECT(this), TQT_SLOT(slotSelectionEllipse()), ac, "SQ Selection Ellipse");
-    pASelectionClear = new KAction(i18n("Clear"), 0, 0, TQT_TQOBJECT(this), TQT_SLOT(slotSelectionClear()), ac, "SQ Selection Clear");
+    pASelectionRect = new TDEToggleAction(i18n("Rectangle"), TQPixmap(locate("data", "images/actions/glselection_rect.png")), 0, TQT_TQOBJECT(this), TQT_SLOT(slotSelectionRect()), ac, "SQ Selection Rect");
+    pASelectionEllipse = new TDEToggleAction(i18n("Ellipse"), TQPixmap(locate("data", "images/actions/glselection_ellipse.png")), 0, TQT_TQOBJECT(this), TQT_SLOT(slotSelectionEllipse()), ac, "SQ Selection Ellipse");
+    pASelectionClear = new TDEAction(i18n("Clear"), 0, 0, TQT_TQOBJECT(this), TQT_SLOT(slotSelectionClear()), ac, "SQ Selection Clear");
 
-    pAZoomW = new KToggleAction(i18n("Fit width"), TQPixmap(locate("data", "images/actions/zoomW.png")), 0, TQT_TQOBJECT(this), TQT_SLOT(slotZoomW()), ac, "SQ ZoomW");
-    pAZoomH = new KToggleAction(i18n("Fit height"), TQPixmap(locate("data", "images/actions/zoomH.png")), 0, TQT_TQOBJECT(this), TQT_SLOT(slotZoomH()), ac, "SQ ZoomH");
-    pAZoomWH = new KToggleAction(i18n("Fit image"), TQPixmap(locate("data", "images/actions/zoomWH.png")), 0, TQT_TQOBJECT(this), TQT_SLOT(slotZoomWH()), ac, "SQ ZoomWH");
-    pAZoom100 = new KToggleAction(i18n("Zoom 100%"), TQPixmap(locate("data", "images/actions/zoom100.png")), 0, TQT_TQOBJECT(this), TQT_SLOT(slotZoom100()), ac, "SQ Zoom100");
-    pAZoomLast = new KToggleAction(i18n("Leave previous zoom"), TQPixmap(locate("data", "images/actions/zoomlast.png")), 0, TQT_TQOBJECT(this), TQT_SLOT(slotZoomLast()), ac, "SQ ZoomLast");
-    pAIfLess = new KToggleAction(i18n("Ignore, if image is smaller than window"), TQPixmap(locate("data", "images/actions/ifless.png")), 0, 0, 0, ac, "if less");
+    pAZoomW = new TDEToggleAction(i18n("Fit width"), TQPixmap(locate("data", "images/actions/zoomW.png")), 0, TQT_TQOBJECT(this), TQT_SLOT(slotZoomW()), ac, "SQ ZoomW");
+    pAZoomH = new TDEToggleAction(i18n("Fit height"), TQPixmap(locate("data", "images/actions/zoomH.png")), 0, TQT_TQOBJECT(this), TQT_SLOT(slotZoomH()), ac, "SQ ZoomH");
+    pAZoomWH = new TDEToggleAction(i18n("Fit image"), TQPixmap(locate("data", "images/actions/zoomWH.png")), 0, TQT_TQOBJECT(this), TQT_SLOT(slotZoomWH()), ac, "SQ ZoomWH");
+    pAZoom100 = new TDEToggleAction(i18n("Zoom 100%"), TQPixmap(locate("data", "images/actions/zoom100.png")), 0, TQT_TQOBJECT(this), TQT_SLOT(slotZoom100()), ac, "SQ Zoom100");
+    pAZoomLast = new TDEToggleAction(i18n("Leave previous zoom"), TQPixmap(locate("data", "images/actions/zoomlast.png")), 0, TQT_TQOBJECT(this), TQT_SLOT(slotZoomLast()), ac, "SQ ZoomLast");
+    pAIfLess = new TDEToggleAction(i18n("Ignore, if image is smaller than window"), TQPixmap(locate("data", "images/actions/ifless.png")), 0, 0, 0, ac, "if less");
 
-    pAFull = new KToggleAction(TQString(), 0, 0, 0, ac, "SQ GL Full");
+    pAFull = new TDEToggleAction(TQString(), 0, 0, 0, ac, "SQ GL Full");
 
     TQString squirrel_zoom_actions = TQString::fromLatin1("squirrel_zoom_actions");
     pAZoomW->setExclusiveGroup(squirrel_zoom_actions);
@@ -115,10 +115,10 @@ void SQ_GLWidget::createActions()
 
 void SQ_GLWidget::createToolbar()
 {
-    zoomMenu = new KPopupMenu;
+    zoomMenu = new TDEPopupMenu;
 
 #ifndef KSQUIRREL_PART
-    selectionMenu = new KPopupMenu;
+    selectionMenu = new TDEPopupMenu;
 
     SQ_ToolButton    *pATool;
 
@@ -156,12 +156,12 @@ void SQ_GLWidget::createToolbar()
 
 /*
  * We will create TQToolButtons and put them in toolbar.
- * Of course, we can just KAction::plug(), BUT plugged KActions
+ * Of course, we can just TDEAction::plug(), BUT plugged TDEActions
  * will produce buttons, which cann't be clicked twise! I think
- * plugged KActions will treat our attempt as double-click, not two single-clicks.
+ * plugged TDEActions will treat our attempt as double-click, not two single-clicks.
  * On the other hand, we can click TQToolButton as frequently as we want.
  *
- * Plugged KActions also don't know about autorepeat :(
+ * Plugged TDEActions also don't know about autorepeat :(
  */
     new SQ_ToolButton(TQPixmap(locate("data", "images/actions/file_first.png")), i18n("Go to first image"), TQT_TQOBJECT(this), TQT_SLOT(slotFirst()), toolbar);
     pATool = new SQ_ToolButton(TQPixmap(locate("data", "images/actions/file_prev.png")), i18n("Previous image"), TQT_TQOBJECT(this), TQT_SLOT(slotPrev()), toolbar);
@@ -220,7 +220,7 @@ void SQ_GLWidget::slotProperties()
     stopAnimation();
 
     const int real_size = tab->finfo.image[tab->current].w * tab->finfo.image[tab->current].h * sizeof(RGBA);
-    TQString sz = KIO::convertSize(real_size);
+    TQString sz = TDEIO::convertSize(real_size);
     TQStringList list;
 
     TQValueVector<TQPair<TQString,TQString> > meta;
@@ -544,7 +544,7 @@ void SQ_GLWidget::saveAs()
         default: scgetter = SQ_GLHelpers::scanLine0;
     }
 
-    RGBA scan[w];
+    RGBA *scan = new RGBA[w];
     RGBA *data = tab->parts[tab->current].buffer->data();
 
     fmt_image im2 = im;
@@ -563,6 +563,7 @@ void SQ_GLWidget::saveAs()
     if(err != SQE_OK)
     {
         KMessageBox::error(this, i18n("Error writing image"));
+        delete [] scan;
         return;
     }
 
@@ -571,6 +572,7 @@ void SQ_GLWidget::saveAs()
     if(err != SQE_OK)
     {
         KMessageBox::error(this, i18n("Error writing image"));
+        delete [] scan;
         return;
     }
 
@@ -593,23 +595,25 @@ void SQ_GLWidget::saveAs()
         {
             wlib->codec->write_close();
             KMessageBox::error(this, i18n("Error writing image"));
+            delete [] scan;
             return;
         }
     }
 
     wlib->codec->write_close();
+    delete [] scan;
 
     // copy to non-local directory
     if(!url.isLocalFile())
     {
         //                           src   dst  perm  overwrite resume  progress
-        KIO::Job *j = KIO::file_copy(path, url, -1,   true,     false,  false);
+        TDEIO::Job *j = TDEIO::file_copy(path, url, -1,   true,     false,  false);
 
-        connect(j, TQT_SIGNAL(result(KIO::Job *)), TQT_TQOBJECT(this), TQT_SLOT(slotCopyResult(KIO::Job *)));
+        connect(j, TQT_SIGNAL(result(TDEIO::Job *)), TQT_TQOBJECT(this), TQT_SLOT(slotCopyResult(TDEIO::Job *)));
     }
 }
 
-void SQ_GLWidget::slotCopyResult(KIO::Job *job)
+void SQ_GLWidget::slotCopyResult(TDEIO::Job *job)
 {
     if(job->error())
     {
@@ -627,8 +631,8 @@ void SQ_GLWidget::slotCopyResult(KIO::Job *job)
             if(result == TQDialog::Rejected || d.selectedURL().isEmpty())
                 return;
 
-            KIO::Job *j = KIO::file_copy(tmp->name(), d.selectedURL(), -1, true, false, false);
-            connect(j, TQT_SIGNAL(result(KIO::Job *)), TQT_TQOBJECT(this), TQT_SLOT(slotCopyResult(KIO::Job *)));
+            TDEIO::Job *j = TDEIO::file_copy(tmp->name(), d.selectedURL(), -1, true, false, false);
+            connect(j, TQT_SIGNAL(result(TDEIO::Job *)), TQT_TQOBJECT(this), TQT_SLOT(slotCopyResult(TDEIO::Job *)));
         }
     }
 }
@@ -644,9 +648,9 @@ void SQ_GLWidget::toClipboard()
 
     // image doesn't have extra regions
     if(tab->parts[tab->current].realw == tab->parts[tab->current].w && tab->parts[tab->current].realh == tab->parts[tab->current].h)
-        KApplication::clipboard()->setImage(im, TQClipboard::Clipboard);
+        TDEApplication::clipboard()->setImage(im, TQClipboard::Clipboard);
     else
-        KApplication::clipboard()->setImage(im.copy(0, 0, tab->parts[tab->current].w, tab->parts[tab->current].h), TQClipboard::Clipboard);
+        TDEApplication::clipboard()->setImage(im.copy(0, 0, tab->parts[tab->current].w, tab->parts[tab->current].h), TQClipboard::Clipboard);
 }
 
 void SQ_GLWidget::bcg()
@@ -855,9 +859,9 @@ void SQ_GLWidget::initAccelsAndMenu()
     menuImage = new TQPopupMenu(menu);
     menuFile = new TQPopupMenu(menu);
 
-    menu->insertItem(SQ_IconLoader::instance()->loadIcon("icons", KIcon::Desktop, KIcon::SizeSmall), i18n("File"), menuFile);
-    menu->insertItem(SQ_IconLoader::instance()->loadIcon("view_orientation", KIcon::Desktop, KIcon::SizeSmall), i18n("Rotate"), menuRotate);
-    menu->insertItem(SQ_IconLoader::instance()->loadIcon("viewmag", KIcon::Desktop, KIcon::SizeSmall), i18n("Zoom"), menuZoom);
+    menu->insertItem(SQ_IconLoader::instance()->loadIcon("icons", TDEIcon::Desktop, TDEIcon::SizeSmall), i18n("File"), menuFile);
+    menu->insertItem(SQ_IconLoader::instance()->loadIcon("view_orientation", TDEIcon::Desktop, TDEIcon::SizeSmall), i18n("Rotate"), menuRotate);
+    menu->insertItem(SQ_IconLoader::instance()->loadIcon("viewmag", TDEIcon::Desktop, TDEIcon::SizeSmall), i18n("Zoom"), menuZoom);
     menu->insertItem(i18n("Move"), menuMove);
 
 #ifndef KSQUIRREL_PART
@@ -867,9 +871,9 @@ void SQ_GLWidget::initAccelsAndMenu()
     menu->insertItem(i18n("Image"), menuImage);
 
 #define SQ_ADD_KACTION(b) \
-    (new KAction(TQString(), b, TQT_TQOBJECT(this), TQT_SLOT(slotAccelActivated()), ac, TQString::fromLatin1("action_%1").arg(b)))
+    (new TDEAction(TQString(), b, TQT_TQOBJECT(this), TQT_SLOT(slotAccelActivated()), ac, TQString::fromLatin1("action_%1").arg(b)))
 
-    id_saveas = menuFile->insertItem(SQ_IconLoader::instance()->loadIcon("filesaveas", KIcon::Desktop, KIcon::SizeSmall), i18n("Save As...") + "\tS", SQ_ADD_KACTION(TQt::Key_S), TQT_SLOT(activate()));
+    id_saveas = menuFile->insertItem(SQ_IconLoader::instance()->loadIcon("document-save-as", TDEIcon::Desktop, TDEIcon::SizeSmall), i18n("Save As...") + "\tS", SQ_ADD_KACTION(TQt::Key_S), TQT_SLOT(activate()));
 
 #ifndef KSQUIRREL_PART
     menuFile->insertSeparator();
@@ -929,7 +933,7 @@ void SQ_GLWidget::initAccelsAndMenu()
     menuImage->insertItem(i18n("To clipboard") + "\tQ", SQ_ADD_KACTION(TQt::Key_Q), TQT_SLOT(activate()));
     menuImage->insertItem(i18n("Print") + "\tCtrl+P", SQ_ADD_KACTION(TQt::Key_P+CTRL), TQT_SLOT(activate()));
     menuImage->insertSeparator();
-    id_settings = menuImage->insertItem(SQ_IconLoader::instance()->loadIcon("configure", KIcon::Desktop, KIcon::SizeSmall), i18n("Codec settings") + "\tC", SQ_ADD_KACTION(TQt::Key_C), TQT_SLOT(activate()));
+    id_settings = menuImage->insertItem(SQ_IconLoader::instance()->loadIcon("configure", TDEIcon::Desktop, TDEIcon::SizeSmall), i18n("Codec settings") + "\tC", SQ_ADD_KACTION(TQt::Key_C), TQT_SLOT(activate()));
     menuImage->setItemEnabled(id_settings, false);
     menuImage->insertSeparator();
     menuImage->insertItem(i18n("Color balance...") + "\tD", SQ_ADD_KACTION(TQt::Key_D), TQT_SLOT(activate()));
@@ -992,9 +996,9 @@ void SQ_GLWidget::initAccelsAndMenu()
 
 void SQ_GLWidget::slotAccelActivated()
 {
-    KAction *accel = static_cast<KAction *>(TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME *>(sender())));
+    TDEAction *accel = static_cast<TDEAction *>(TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME *>(sender())));
 
-    KShortcut ks = accel->shortcut();
+    TDEShortcut ks = accel->shortcut();
 
          if(!ks.compare(TQt::Key_Left))        matrix_move(movefactor, 0);
     else if(!ks.compare(TQt::Key_Right))       matrix_move(-movefactor, 0);
@@ -1061,27 +1065,27 @@ void SQ_GLWidget::slotAccelActivated()
             return;
 
         lastCopy = url;
-        KIO::Job *job;
+        TDEIO::Job *job;
 
         if(!ks.compare(TQt::Key_F5))
-            job = KIO::copy(tab->m_original, url);
+            job = TDEIO::copy(tab->m_original, url);
         else
-            job = KIO::move(tab->m_original, url);
+            job = TDEIO::move(tab->m_original, url);
 
         job->setWindow(this);
-        connect(job, TQT_SIGNAL(result(KIO::Job *)), TQT_TQOBJECT(this), TQT_SLOT(slotCopyJobResult(KIO::Job *)));
+        connect(job, TQT_SIGNAL(result(TDEIO::Job *)), TQT_TQOBJECT(this), TQT_SLOT(slotCopyJobResult(TDEIO::Job *)));
     }
     else if(!ks.compare(TQt::Key_F7) || !ks.compare(TQt::Key_F8))
     {
-        KIO::Job *job;
+        TDEIO::Job *job;
 
         if(!ks.compare(TQt::Key_F6))
-            job = KIO::copy(tab->m_original, lastCopy);
+            job = TDEIO::copy(tab->m_original, lastCopy);
         else
-            job = KIO::move(tab->m_original, lastCopy);
+            job = TDEIO::move(tab->m_original, lastCopy);
 
         job->setWindow(this);
-        connect(job, TQT_SIGNAL(result(KIO::Job *)), TQT_TQOBJECT(this), TQT_SLOT(slotCopyJobResult(KIO::Job *)));
+        connect(job, TQT_SIGNAL(result(TDEIO::Job *)), TQT_TQOBJECT(this), TQT_SLOT(slotCopyJobResult(TDEIO::Job *)));
     }
     else if(!ks.compare(TQt::Key_F9))         copyURL();
     else if(!ks.compare(TQt::Key_Slash))      slotShowHelp();
@@ -1143,7 +1147,7 @@ void SQ_GLWidget::zoom(GLfloat val)
     matrix_zoom(val);
 }
 
-void SQ_GLWidget::slotCopyJobResult(KIO::Job *job)
+void SQ_GLWidget::slotCopyJobResult(TDEIO::Job *job)
 {
     if(job->error())
         job->showErrorDialog(this);
@@ -1224,7 +1228,7 @@ void SQ_GLWidget::crop()
     {
         KMessageBox::error(this,
                     i18n("Memory allocation failed for %1 of memory")
-                    .arg(KIO::convertSize(pp.realw * pp.realh * sizeof(RGBA))));
+                    .arg(TDEIO::convertSize(pp.realw * pp.realh * sizeof(RGBA))));
         return;
     }
 
@@ -1325,10 +1329,10 @@ void SQ_GLWidget::slotChangeTab(int id)
 
 #ifndef KSQUIRREL_PART
             SQ_GLView::window()->sbarWidget("SBFile")->setText(tab->m_original.fileName(false));
-            SQ_GLView::window()->sbarWidget("SBLoaded")->setText(KGlobal::locale()->formatLong(tab->elapsed) + i18n(" ms."));
+            SQ_GLView::window()->sbarWidget("SBLoaded")->setText(TDEGlobal::locale()->formatLong(tab->elapsed) + i18n(" ms."));
 #else
             t_glv.sbarWidget("SBFile")->setText(tab->m_original.fileName(false));
-            t_glv.sbarWidget("SBLoaded")->setText(KGlobal::locale()->formatLong(tab->elapsed) + i18n(" ms."));
+            t_glv.sbarWidget("SBLoaded")->setText(TDEGlobal::locale()->formatLong(tab->elapsed) + i18n(" ms."));
 #endif
         }
         else
@@ -1394,7 +1398,7 @@ void SQ_GLWidget::slotCloseRequest(int index)
                         Qt::NoButton,
                         Qt::NoButton);
 
-    KApplication::sendEvent(SQ_GLView::window()->tabbar(), &ev);
+    TDEApplication::sendEvent(SQ_GLView::window()->tabbar(), &ev);
 
     std::vector<Tab>::iterator itEnd = tabs.end();
     std::vector<Tab>::iterator it = tabs.begin();
