@@ -41,7 +41,7 @@ SQ_MountView::SQ_MountView(TQWidget *parent, const char *name) : TDEListView(par
     popup = new TDEPopupMenu;
     id_mount = popup->insertItem(SQ_IconLoader::instance()->loadIcon("drive-harddisk-mounted", TDEIcon::Desktop, TDEIcon::SizeSmall),
                 i18n("Mount"), this, TQT_SLOT(slotMount()));
-    id_unmount = popup->insertItem(SQ_IconLoader::instance()->loadIcon("drive-harddisk", TDEIcon::Desktop, TDEIcon::SizeSmall),
+    id_unmount = popup->insertItem(SQ_IconLoader::instance()->loadIcon("drive-harddisk-unmounted", TDEIcon::Desktop, TDEIcon::SizeSmall),
                 i18n("Unmount"), this, TQT_SLOT(slotUnmount()));
     popup->insertItem(SQ_IconLoader::instance()->loadIcon("reload", TDEIcon::Desktop, TDEIcon::SizeSmall),
                 i18n("Refresh"), this, TQT_SLOT(slotRefresh()));
