@@ -24,7 +24,7 @@
 #include <tqtimer.h>
 #include <tqcursor.h>
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kurldrag.h>
 #include <kurl.h>
 #include <kdirwatch.h>
@@ -91,7 +91,7 @@ SQ_TreeView::SQ_TreeView(TQWidget *parent, const char *name) : KFileTreeView(par
     setColumnWidth(1, 18);
 
     root = new SQ_FileTreeViewBranch(this, TQDir::rootDirPath(), TQString(),
-        SQ_IconLoader::instance()->loadIcon("folder_red", KIcon::Desktop, KIcon::SizeSmall));
+        SQ_IconLoader::instance()->loadIcon("folder_red", TDEIcon::Desktop, TDEIcon::SizeSmall));
 
     // some hacks to create our SQ_TreeViewItem as root item
     SQ_TreeViewItem  *ritem = new SQ_TreeViewItem(this,
@@ -143,8 +143,8 @@ SQ_TreeView::SQ_TreeView(TQWidget *parent, const char *name) : KFileTreeView(par
     connect(this, TQT_SIGNAL(dropped(TQDropEvent *, TQListViewItem *, TQListViewItem *)),
             this, TQT_SLOT(slotDropped(TQDropEvent *, TQListViewItem *, TQListViewItem *)));
 
-    connect(this, TQT_SIGNAL(contextMenu(KListView *, TQListViewItem *, const TQPoint &)),
-            this, TQT_SLOT(slotContextMenu(KListView *, TQListViewItem *, const TQPoint &)));
+    connect(this, TQT_SIGNAL(contextMenu(TDEListView *, TQListViewItem *, const TQPoint &)),
+            this, TQT_SLOT(slotContextMenu(TDEListView *, TQListViewItem *, const TQPoint &)));
 
     menu = new SQ_TreeViewMenu(this);
 
@@ -624,7 +624,7 @@ void SQ_TreeView::slotDropped(TQDropEvent *e, TQListViewItem *parent, TQListView
     SQ_NavigatorDropMenu::instance()->exec(TQCursor::pos(), true);
 }
 
-void SQ_TreeView::slotContextMenu(KListView *, TQListViewItem *item, const TQPoint &point)
+void SQ_TreeView::slotContextMenu(TDEListView *, TQListViewItem *item, const TQPoint &point)
 {
     if(item)
     {
