@@ -1,17 +1,17 @@
 #ifndef SQ_TREEVIEWMENU_H
 #define SQ_TREEVIEWMENU_H
 
-#include <kpopupmenu.h>
+#include <tdepopupmenu.h>
 #include <kurl.h>
 
 class TQPoint;
 
-namespace KIO { class Job; }
+namespace TDEIO { class Job; }
 
-class SQ_TreeViewMenu : public KPopupMenu
+class SQ_TreeViewMenu : public TDEPopupMenu
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 
     public:
         SQ_TreeViewMenu(TQWidget *parent = 0, const char *name = 0);
@@ -30,11 +30,11 @@ class SQ_TreeViewMenu : public KPopupMenu
         virtual void slotDirectoryRename();
         virtual void slotDirectoryDelete();
         virtual void slotDirectoryProperties();
-        virtual void slotDirectoryResult(KIO::Job *job);
+        virtual void slotDirectoryResult(TDEIO::Job *job);
 
         void slotDirectoryClear();
-        void slotEntries(KIO::Job *, const KIO::UDSEntryList &);
-        void slotListResult(KIO::Job *);
+        void slotEntries(TDEIO::Job *, const TDEIO::UDSEntryList &);
+        void slotListResult(TDEIO::Job *);
 
     protected:
         int id_new, id_rename, id_delete, id_prop, id_clear;
